# Welcome to Bagels!

Bagels is a powerful expense tracker that lives in your terminal.

---

## The focus system

- The section you are currently focusing has a **bright border**.
- The bottom bar provides the bindings used to execute actions for the focused section.
- Use `TAB` to switch between sections, or use `Jump mode` instead.
- The first three section on the left affect the displayed insights, as well as the records you view and create.

## Getting started

To begin, **add an account**!

> Hint:
> Focus on the accounts section and find the bindings to add an account.

## Themes

You can change the theme of Bagels with the `theme` command from the command palette!
